"""devicons2 lib."""

from konstantin_docs.dia.c4.base import BaseSprites


class Devicons2Lib(BaseSprites):
    """Библиотека спрайтов."""

    AARCH64 = "aarch64"
    AFTEREFFECTS = "aftereffects"
    AMAZONWEBSERVICES_ORIGINAL = "amazonwebservices_original"
    AMAZONWEBSERVICES_WORDMARK = "amazonwebservices_wordmark"
    ANDROID = "android"
    ANDROID_WORDMARK = "android_wordmark"
    ANGULARJS = "angularjs"
    ANGULARJS_WORDMARK = "angularjs_wordmark"
    APACHE = "apache"
    APACHE_LINE = "apache_line"
    APACHE_LINE_WORDMARK = "apache_line_wordmark"
    APACHE_WORDMARK = "apache_wordmark"
    APPCELERATOR_ORIGINAL = "appcelerator_original"
    APPCELERATOR_WORDMARK = "appcelerator_wordmark"
    APPLE_ORIGINAL = "apple_original"
    APPWRITE = "appwrite"
    APPWRITE_WORDMARK = "appwrite_wordmark"
    ATOM_ORIGINAL = "atom_original"
    ATOM_ORIGINAL_WORDMARK = "atom_original_wordmark"
    BABEL = "babel"
    BACKBONEJS = "backbonejs"
    BACKBONEJS_WORDMARK = "backbonejs_wordmark"
    BASH = "bash"
    BEHANCE = "behance"
    BEHANCE_WORDMARK = "behance_wordmark"
    BITBUCKET_ORIGINAL = "bitbucket_original"
    BITBUCKET_ORIGINAL_WORDMARK = "bitbucket_original_wordmark"
    BOOTSTRAP = "bootstrap"
    BOOTSTRAP_WORDMARK = "bootstrap_wordmark"
    BOWER = "bower"
    BOWER_LINE = "bower_line"
    BOWER_LINE_WORDMARK = "bower_line_wordmark"
    BOWER_WORDMARK = "bower_wordmark"
    BULMA = "bulma"
    C = "c"
    C_LINE = "c_line"
    CAKEPHP = "cakephp"
    CAKEPHP_WORDMARK = "cakephp_wordmark"
    CEYLON = "ceylon"
    CHROME = "chrome"
    CHROME_WORDMARK = "chrome_wordmark"
    CIRCLECI = "circleci"
    CIRCLECI_WORDMARK = "circleci_wordmark"
    CLOJURE_LINE = "clojure_line"
    CLOJURESCRIPT = "clojurescript"
    CODECOV = "codecov"
    CODEIGNITER = "codeigniter"
    CODEIGNITER_WORDMARK = "codeigniter_wordmark"
    CODEPEN = "codepen"
    CODEPEN_ORIGINAL_WORDMARK = "codepen_original_wordmark"
    COFFEESCRIPT_ORIGINAL = "coffeescript_original"
    COFFEESCRIPT_ORIGINAL_WORDMARK = "coffeescript_original_wordmark"
    COMPOSER_LINE = "composer_line"
    COMPOSER_LINE_WORDMARK = "composer_line_wordmark"
    CONFLUENCE_ORIGINAL = "confluence_original"
    CONFLUENCE_ORIGINAL_WORDMARK = "confluence_original_wordmark"
    COUCHDB = "couchdb"
    COUCHDB_WORDMARK = "couchdb_wordmark"
    CPLUSPLUS = "cplusplus"
    CPLUSPLUS_LINE = "cplusplus_line"
    CRYSTAL_ORIGINAL = "crystal_original"
    CRYSTAL_ORIGINAL_WORDMARK = "crystal_original_wordmark"
    CSHARP = "csharp"
    CSHARP_LINE = "csharp_line"
    CSS3 = "css3"
    CSS3_WORDMARK = "css3_wordmark"
    CUCUMBER = "cucumber"
    CUCUMBER_WORDMARK = "cucumber_wordmark"
    D3JS = "d3js"
    D3JS_ORIGINAL = "d3js_original"
    DART = "dart"
    DART_WORDMARK = "dart_wordmark"
    DEBIAN = "debian"
    DEBIAN_WORDMARK = "debian_wordmark"
    DEVICON = "devicon"
    DEVICON_WORDMARK = "devicon_wordmark"
    DIGITALOCEAN = "digitalocean"
    DIGITALOCEAN_WORDMARK = "digitalocean_wordmark"
    DJANGO = "django"
    DJANGO_LINE = "django_line"
    DOCKER = "docker"
    DOCKER_WORDMARK = "docker_wordmark"
    DOCTRINE = "doctrine"
    DOCTRINE_LINE = "doctrine_line"
    DOCTRINE_LINE_WORDMARK = "doctrine_line_wordmark"
    DOCTRINE_WORDMARK = "doctrine_wordmark"
    DOT_NET = "dot_net"
    DOT_NET_WORDMARK = "dot_net_wordmark"
    DOTNETCORE = "dotnetcore"
    DRUPAL = "drupal"
    DRUPAL_WORDMARK = "drupal_wordmark"
    ELECTRON_ORIGINAL = "electron_original"
    ELECTRON_ORIGINAL_WORDMARK = "electron_original_wordmark"
    ELEVENTY = "eleventy"
    ELIXIR = "elixir"
    ELIXIR_WORDMARK = "elixir_wordmark"
    ELM = "elm"
    ELM_WORDMARK = "elm_wordmark"
    EMBEDDEDC = "embeddedc"
    EMBEDDEDC_WORDMARK = "embeddedc_wordmark"
    EMBER_ORIGINAL_WORDMARK = "ember_original_wordmark"
    ERLANG = "erlang"
    ERLANG_WORDMARK = "erlang_wordmark"
    EXPRESS_ORIGINAL = "express_original"
    EXPRESS_ORIGINAL_WORDMARK = "express_original_wordmark"
    FACEBOOK = "facebook"
    FIGMA = "figma"
    FIREBASE = "firebase"
    FIREBASE_WORDMARK = "firebase_wordmark"
    FIREFOX = "firefox"
    FIREFOX_WORDMARK = "firefox_wordmark"
    FLASK_ORIGINAL = "flask_original"
    FLASK_ORIGINAL_WORDMARK = "flask_original_wordmark"
    FLUTTER = "flutter"
    FOUNDATION = "foundation"
    FOUNDATION_WORDMARK = "foundation_wordmark"
    FSHARP = "fsharp"
    GATLING = "gatling"
    GATLING_WORDMARK = "gatling_wordmark"
    GATSBY = "gatsby"
    GATSBY_WORDMARK = "gatsby_wordmark"
    GIMP = "gimp"
    GIT = "git"
    GIT_WORDMARK = "git_wordmark"
    GITHUB_ORIGINAL = "github_original"
    GITHUB_ORIGINAL_WORDMARK = "github_original_wordmark"
    GITLAB = "gitlab"
    GITLAB_WORDMARK = "gitlab_wordmark"
    GITTER = "gitter"
    GITTER_WORDMARK = "gitter_wordmark"
    GO = "go"
    GO_LINE = "go_line"
    GODOT = "godot"
    GODOT_WORDMARK = "godot_wordmark"
    GOOGLE = "google"
    GOOGLE_WORDMARK = "google_wordmark"
    GOOGLECLOUD = "googlecloud"
    GOOGLECLOUD_WORDMARK = "googlecloud_wordmark"
    GRADLE = "gradle"
    GRADLE_WORDMARK = "gradle_wordmark"
    GRAILS = "grails"
    GRAPHQL = "graphql"
    GRAPHQL_WORDMARK = "graphql_wordmark"
    GROOVY = "groovy"
    GRUNT = "grunt"
    GRUNT_LINE = "grunt_line"
    GRUNT_LINE_WORDMARK = "grunt_line_wordmark"
    GRUNT_WORDMARK = "grunt_wordmark"
    GULP = "gulp"
    HANDLEBARS = "handlebars"
    HANDLEBARS_WORDMARK = "handlebars_wordmark"
    HASKELL = "haskell"
    HASKELL_WORDMARK = "haskell_wordmark"
    HAXE = "haxe"
    HEROKU = "heroku"
    HEROKU_LINE = "heroku_line"
    HEROKU_LINE_WORDMARK = "heroku_line_wordmark"
    HEROKU_WORDMARK = "heroku_wordmark"
    HTML5 = "html5"
    HTML5_WORDMARK = "html5_wordmark"
    IE10_ORIGINAL = "ie10_original"
    ILLUSTRATOR = "illustrator"
    ILLUSTRATOR_LINE = "illustrator_line"
    INDEX = "index"
    INKSCAPE = "inkscape"
    INKSCAPE_WORDMARK = "inkscape_wordmark"
    INTELLIJ = "intellij"
    INTELLIJ_WORDMARK = "intellij_wordmark"
    IONIC_ORIGINAL = "ionic_original"
    IONIC_ORIGINAL_WORDMARK = "ionic_original_wordmark"
    JASMINE = "jasmine"
    JASMINE_WORDMARK = "jasmine_wordmark"
    JAVA = "java"
    JAVA_WORDMARK = "java_wordmark"
    JAVASCRIPT = "javascript"
    JEET = "jeet"
    JEET_WORDMARK = "jeet_wordmark"
    JENKINS = "jenkins"
    JENKINS_LINE = "jenkins_line"
    JEST = "jest"
    JETBRAINS = "jetbrains"
    JQUERY = "jquery"
    JQUERY_WORDMARK = "jquery_wordmark"
    JULIA = "julia"
    JULIA_WORDMARK = "julia_wordmark"
    JUPYTER = "jupyter"
    JUPYTER_WORDMARK = "jupyter_wordmark"
    KARMA = "karma"
    KNOCKOUT_WORDMARK = "knockout_wordmark"
    KOTLIN = "kotlin"
    KOTLIN_WORDMARK = "kotlin_wordmark"
    KRAKENJS = "krakenjs"
    KRAKENJS_WORDMARK = "krakenjs_wordmark"
    KUBERNETES = "kubernetes"
    KUBERNETES_WORDMARK = "kubernetes_wordmark"
    LABVIEW = "labview"
    LABVIEW_WORDMARK = "labview_wordmark"
    LARAVEL = "laravel"
    LARAVEL_WORDMARK = "laravel_wordmark"
    LESS_WORDMARK = "less_wordmark"
    LINKEDIN = "linkedin"
    LINKEDIN_WORDMARK = "linkedin_wordmark"
    LINUX = "linux"
    LUA = "lua"
    LUA_WORDMARK = "lua_wordmark"
    MAGENTO_LINE = "magento_line"
    MAGENTO_ORIGINAL = "magento_original"
    MAGENTO_ORIGINAL_WORDMARK = "magento_original_wordmark"
    MATERIALUI = "materialui"
    MATLAB = "matlab"
    MATLAB_LINE = "matlab_line"
    METEOR = "meteor"
    METEOR_WORDMARK = "meteor_wordmark"
    MICROSOFTSQLSERVER = "microsoftsqlserver"
    MICROSOFTSQLSERVER_WORDMARK = "microsoftsqlserver_wordmark"
    MINITAB = "minitab"
    MOCHA = "mocha"
    MODX = "modx"
    MODX_WORDMARK = "modx_wordmark"
    MONGODB = "mongodb"
    MONGODB_WORDMARK = "mongodb_wordmark"
    MOODLE = "moodle"
    MOODLE_WORDMARK = "moodle_wordmark"
    MYSQL = "mysql"
    MYSQL_WORDMARK = "mysql_wordmark"
    NESTJS = "nestjs"
    NESTJS_WORDMARK = "nestjs_wordmark"
    NEXTJS_LINE = "nextjs_line"
    NEXTJS_ORIGINAL = "nextjs_original"
    NEXTJS_ORIGINAL_WORDMARK = "nextjs_original_wordmark"
    NGINX_ORIGINAL = "nginx_original"
    NIXOS = "nixos"
    NIXOS_WORDMARK = "nixos_wordmark"
    NODEJS = "nodejs"
    NODEJS_WORDMARK = "nodejs_wordmark"
    NODEWEBKIT = "nodewebkit"
    NODEWEBKIT_LINE = "nodewebkit_line"
    NODEWEBKIT_LINE_WORDMARK = "nodewebkit_line_wordmark"
    NODEWEBKIT_WORDMARK = "nodewebkit_wordmark"
    NPM_ORIGINAL_WORDMARK = "npm_original_wordmark"
    OBJECTIVEC = "objectivec"
    OCAML = "ocaml"
    OCAML_WORDMARK = "ocaml_wordmark"
    ORACLE_ORIGINAL = "oracle_original"
    PERL = "perl"
    PHALCON = "phalcon"
    PHOENIX = "phoenix"
    PHOENIX_WORDMARK = "phoenix_wordmark"
    PHOTOSHOP = "photoshop"
    PHOTOSHOP_LINE = "photoshop_line"
    PHP = "php"
    PHPSTORM = "phpstorm"
    PHPSTORM_WORDMARK = "phpstorm_wordmark"
    POSTGRESQL = "postgresql"
    POSTGRESQL_WORDMARK = "postgresql_wordmark"
    PREMIEREPRO = "premierepro"
    PROTRACTOR = "protractor"
    PROTRACTOR_WORDMARK = "protractor_wordmark"
    PYCHARM = "pycharm"
    PYCHARM_WORDMARK = "pycharm_wordmark"
    PYTHON = "python"
    PYTHON_WORDMARK = "python_wordmark"
    R = "r"
    R_ORIGINAL = "r_original"
    RAILS = "rails"
    RAILS_WORDMARK = "rails_wordmark"
    RASPBERRYPI_LINE = "raspberrypi_line"
    RASPBERRYPI_LINE_WORDMARK = "raspberrypi_line_wordmark"
    REACT_ORIGINAL = "react_original"
    REACT_ORIGINAL_WORDMARK = "react_original_wordmark"
    REDHAT = "redhat"
    REDHAT_WORDMARK = "redhat_wordmark"
    REDIS = "redis"
    REDIS_WORDMARK = "redis_wordmark"
    REDUX_ORIGINAL = "redux_original"
    ROCKSDB = "rocksdb"
    RSTUDIO = "rstudio"
    RUBY = "ruby"
    RUBY_WORDMARK = "ruby_wordmark"
    RUBYMINE = "rubymine"
    RUBYMINE_WORDMARK = "rubymine_wordmark"
    RUST = "rust"
    SAFARI = "safari"
    SAFARI_LINE = "safari_line"
    SAFARI_LINE_WORDMARK = "safari_line_wordmark"
    SAFARI_WORDMARK = "safari_wordmark"
    SALESFORCE = "salesforce"
    SASS_ORIGINAL = "sass_original"
    SCALA = "scala"
    SCALA_WORDMARK = "scala_wordmark"
    SEQUELIZE = "sequelize"
    SEQUELIZE_WORDMARK = "sequelize_wordmark"
    SHOPWARE_ORIGINAL = "shopware_original"
    SHOPWARE_ORIGINAL_WORDMARK = "shopware_original_wordmark"
    SKETCH_LINE = "sketch_line"
    SKETCH_LINE_WORDMARK = "sketch_line_wordmark"
    SLACK = "slack"
    SLACK_WORDMARK = "slack_wordmark"
    SOURCETREE_ORIGINAL = "sourcetree_original"
    SOURCETREE_ORIGINAL_WORDMARK = "sourcetree_original_wordmark"
    SPRING = "spring"
    SPRING_WORDMARK = "spring_wordmark"
    SPSS = "spss"
    SQLALCHEMY = "sqlalchemy"
    SQLALCHEMY_ORIGINAL_WORDMARK = "sqlalchemy_original_wordmark"
    SSH_ORIGINAL = "ssh_original"
    SSH_ORIGINAL_WORDMARK = "ssh_original_wordmark"
    STYLUS_ORIGINAL = "stylus_original"
    SWIFT = "swift"
    SWIFT_WORDMARK = "swift_wordmark"
    SYMFONY_ORIGINAL = "symfony_original"
    SYMFONY_ORIGINAL_WORDMARK = "symfony_original_wordmark"
    TAILWINDCSS = "tailwindcss"
    TAILWINDCSS_ORIGINAL_WORDMARK = "tailwindcss_original_wordmark"
    TENSORFLOW_LINE = "tensorflow_line"
    TENSORFLOW_LINE_WORDMARK = "tensorflow_line_wordmark"
    TENSORFLOW_ORIGINAL = "tensorflow_original"
    TENSORFLOW_ORIGINAL_WORDMARK = "tensorflow_original_wordmark"
    THEALGORITHMS = "thealgorithms"
    THEALGORITHMS_WORDMARK = "thealgorithms_wordmark"
    TOMCAT_LINE = "tomcat_line"
    TOMCAT_LINE_WORDMARK = "tomcat_line_wordmark"
    TRAVIS = "travis"
    TRAVIS_WORDMARK = "travis_wordmark"
    TRELLO = "trello"
    TRELLO_WORDMARK = "trello_wordmark"
    TWITTER_ORIGINAL = "twitter_original"
    TYPESCRIPT = "typescript"
    TYPO3 = "typo3"
    TYPO3_WORDMARK = "typo3_wordmark"
    UBUNTU = "ubuntu"
    UBUNTU_WORDMARK = "ubuntu_wordmark"
    UNIX_ORIGINAL = "unix_original"
    UWSGI = "uwsgi"
    VAGRANT = "vagrant"
    VAGRANT_WORDMARK = "vagrant_wordmark"
    VIM = "vim"
    VISUALSTUDIO = "visualstudio"
    VISUALSTUDIO_WORDMARK = "visualstudio_wordmark"
    VSCODE = "vscode"
    VSCODE_WORDMARK = "vscode_wordmark"
    VUEJS = "vuejs"
    VUEJS_LINE = "vuejs_line"
    VUEJS_LINE_WORDMARK = "vuejs_line_wordmark"
    VUEJS_WORDMARK = "vuejs_wordmark"
    VUESTOREFRONT = "vuestorefront"
    WEBLATE = "weblate"
    WEBLATE_WORDMARK = "weblate_wordmark"
    WEBPACK = "webpack"
    WEBPACK_WORDMARK = "webpack_wordmark"
    WEBSTORM = "webstorm"
    WEBSTORM_WORDMARK = "webstorm_wordmark"
    WINDOWS8_ORIGINAL = "windows8_original"
    WINDOWS8_ORIGINAL_WORDMARK = "windows8_original_wordmark"
    WOOCOMMERCE = "woocommerce"
    WOOCOMMERCE_WORDMARK = "woocommerce_wordmark"
    WORDPRESS = "wordpress"
    WORDPRESS_WORDMARK = "wordpress_wordmark"
    XD = "xd"
    XD_LINE = "xd_line"
    YARN = "yarn"
    YARN_WORDMARK = "yarn_wordmark"
    YII = "yii"
    YII_WORDMARK = "yii_wordmark"
    YUNOHOST = "yunohost"
    ZEND = "zend"
    ZEND_WORDMARK = "zend_wordmark"
    ZIG_ORIGINAL = "zig_original"
    ZIG_WORDMARK = "zig_wordmark"
