"""devicons lib."""

from konstantin_docs.dia.c4.base import BaseSprites


class DeviconsLib(BaseSprites):
    """Библиотека спрайтов."""

    ANDROID = "android"
    ANGULAR = "angular"
    APPCELERATOR = "appcelerator"
    APPLE = "apple"
    APPSTORE = "appstore"
    APTANA = "aptana"
    ASTERISK = "asterisk"
    ATLASSIAN = "atlassian"
    ATOM = "atom"
    AWS = "aws"
    BACKBONE = "backbone"
    BING_SMALL = "bing_small"
    BINTRAY = "bintray"
    BITBUCKET = "bitbucket"
    BLACKBERRY = "blackberry"
    BOOTSTRAP = "bootstrap"
    BOWER = "bower"
    BRACKETS = "brackets"
    BUGSENSE = "bugsense"
    CELLULOID = "celluloid"
    CHROME = "chrome"
    CISCO = "cisco"
    CLOJURE = "clojure"
    CLOJURE_ALT = "clojure_alt"
    CLOUD9 = "cloud9"
    CODA = "coda"
    CODE = "code"
    CODE_BADGE = "code_badge"
    CODEIGNITER = "codeigniter"
    CODEPEN = "codepen"
    CODROPS = "codrops"
    COFFEESCRIPT = "coffeescript"
    COMPASS = "compass"
    COMPOSER = "composer"
    CREATIVECOMMONS = "creativecommons"
    CREATIVECOMMONS_BADGE = "creativecommons_badge"
    CSS3 = "css3"
    CSS3_FULL = "css3_full"
    CSS_TRICKS = "css_tricks"
    CSSDECK = "cssdeck"
    DART = "dart"
    DATABASE = "database"
    DEBIAN = "debian"
    DIGITAL_OCEAN = "digital_ocean"
    DJANGO = "django"
    DLANG = "dlang"
    DOCKER = "docker"
    DOCTRINE = "doctrine"
    DOJO = "dojo"
    DOTNET = "dotnet"
    DREAMWEAVER = "dreamweaver"
    DROPBOX = "dropbox"
    DRUPAL = "drupal"
    ECLIPSE = "eclipse"
    EMBER = "ember"
    ENVATO = "envato"
    ERLANG = "erlang"
    EXTJS = "extjs"
    FIREBASE = "firebase"
    FIREFOX = "firefox"
    FSHARP = "fsharp"
    GHOST = "ghost"
    GHOST_SMALL = "ghost_small"
    GIT = "git"
    GIT_BRANCH = "git_branch"
    GIT_COMMIT = "git_commit"
    GIT_COMPARE = "git_compare"
    GIT_MERGE = "git_merge"
    GIT_PULL_REQUEST = "git_pull_request"
    GITHUB = "github"
    GITHUB_ALT = "github_alt"
    GITHUB_BADGE = "github_badge"
    GITHUB_FULL = "github_full"
    GNU = "gnu"
    GO = "go"
    GOOGLE_ANALYTICS = "google_analytics"
    GOOGLE_CLOUD_PLATFORM = "google_cloud_platform"
    GOOGLE_DRIVE = "google_drive"
    GRAILS = "grails"
    GROOVY = "groovy"
    GRUNT = "grunt"
    GULP = "gulp"
    HACKERNEWS = "hackernews"
    HASKELL = "haskell"
    HEROKU = "heroku"
    HTML5 = "html5"
    HTML5_3D_EFFECTS = "html5_3d_effects"
    HTML5_CONNECTIVITY = "html5_connectivity"
    HTML5_DEVICE_ACCESS = "html5_device_access"
    HTML5_MULTIMEDIA = "html5_multimedia"
    IE = "ie"
    ILLUSTRATOR = "illustrator"
    INDEX = "index"
    INTELLIJ = "intellij"
    IONIC = "ionic"
    JAVA = "java"
    JAVASCRIPT = "javascript"
    JAVASCRIPT_BADGE = "javascript_badge"
    JAVASCRIPT_SHIELD = "javascript_shield"
    JEKYLL_SMALL = "jekyll_small"
    JENKINS = "jenkins"
    JIRA = "jira"
    JOOMLA = "joomla"
    JQUERY = "jquery"
    JQUERY_UI = "jquery_ui"
    KOMODO = "komodo"
    KRAKENJS = "krakenjs"
    KRAKENJS_BADGE = "krakenjs_badge"
    LARAVEL = "laravel"
    LESS = "less"
    LINUX = "linux"
    MAGENTO = "magento"
    MAILCHIMP = "mailchimp"
    MARKDOWN = "markdown"
    MATERIALIZECSS = "materializecss"
    METEOR = "meteor"
    METEORFULL = "meteorfull"
    MITLICENCE = "mitlicence"
    MODERNIZR = "modernizr"
    MONGODB = "mongodb"
    MOOTOOLS = "mootools"
    MOOTOOLS_BADGE = "mootools_badge"
    MOZILLA = "mozilla"
    MSQL_SERVER = "msql_server"
    MYSQL = "mysql"
    NANCY = "nancy"
    NETBEANS = "netbeans"
    NETMAGAZINE = "netmagazine"
    NGINX = "nginx"
    NODEJS = "nodejs"
    NODEJS_SMALL = "nodejs_small"
    NPM = "npm"
    ONEDRIVE = "onedrive"
    OPENSHIFT = "openshift"
    OPENSOURCE = "opensource"
    OPERA = "opera"
    PERL = "perl"
    PHONEGAP = "phonegap"
    PHOTOSHOP = "photoshop"
    PHP = "php"
    POSTGRESQL = "postgresql"
    PROLOG = "prolog"
    PYTHON = "python"
    RACKSPACE = "rackspace"
    RAPHAEL = "raphael"
    RASPBERRY_PI = "raspberry_pi"
    REACT = "react"
    REDHAT = "redhat"
    REDIS = "redis"
    REQUIREJS = "requirejs"
    RESPONSIVE = "responsive"
    RUBY = "ruby"
    RUBY_ON_RAILS = "ruby_on_rails"
    RUBY_ROUGH = "ruby_rough"
    RUST = "rust"
    SAFARI = "safari"
    SASS = "sass"
    SCALA = "scala"
    SCRIPTCS = "scriptcs"
    SCRUM = "scrum"
    SENCHATOUCH = "senchatouch"
    SIZZLEJS = "sizzlejs"
    SMASHING_MAGAZINE = "smashing_magazine"
    SNAP_SVG = "snap_svg"
    SQLLITE = "sqllite"
    STACKOVERFLOW = "stackoverflow"
    STREAMLINE = "streamline"
    STYLUS = "stylus"
    SUBLIME = "sublime"
    SWIFT = "swift"
    SYMFONY = "symfony"
    SYMFONY_BADGE = "symfony_badge"
    TECHCRUNCH = "techcrunch"
    TERMINAL = "terminal"
    TERMINAL_BADGE = "terminal_badge"
    TRAVIS = "travis"
    TRELLO = "trello"
    TYPO3 = "typo3"
    UBUNTU = "ubuntu"
    UIKIT = "uikit"
    UNITY_SMALL = "unity_small"
    VIM = "vim"
    VISUALSTUDIO = "visualstudio"
    W3C = "w3c"
    WEBPLATFORM = "webplatform"
    WINDOWS = "windows"
    WORDPRESS = "wordpress"
    YAHOO = "yahoo"
    YAHOO_SMALL = "yahoo_small"
    YEOMAN = "yeoman"
    YII = "yii"
    ZEND = "zend"
